// Mesure de la resistance d'un CTN
// Calcul de la température à partir de la relation de Steinhart-Hart

#define Vcc 5       // Tension d'alimentation
#define Ro  4700   // Résistance du pont
#define A   1.345609486e-3
#define B   2.291677945e-4
#define C   1.427209262e-7

float u;            // Tension CTN
float R;            // Résistance CTN
float logR;         // ln(R)
float T;            // Température en °C


void setup() {
  Serial.begin(9600);  // Paramétrage du port série
  Serial.print("R = ");             // Début affichage
  Serial.print("; ");
  Serial.println("T = ");

}

void loop() {
  u = analogRead(A0) * 5.0 / 1024; // Lecture tension en V
  R = Ro * u / (Vcc - u);       // Calcul de la résistance
  logR = log(R);                   // Calcul de ln(R)
  T = (1.0 / (A + B * logR + C * logR * logR * logR)); // Calcul de la température
  T = T - 273.15;                   // Conversion en °C
  Serial.print(R);
  Serial.print("; ");
  Serial.println(T);                // Fin affichage
  delay(1000);                     // Temporisation de 1s
}
